package com.huijy.management.service;

import java.util.List;
import com.huijy.management.domain.ShopRoom;
import org.apache.ibatis.annotations.Param;

/**
 * 酒店房间Service接口
 * 
 * @author lishuwen
 * @date 2021-11-10
 */
public interface IShopRoomService 
{
    /**
     * 查询酒店房间
     * 
     * @param id 酒店房间主键
     * @return 酒店房间
     */
    public ShopRoom selectShopRoomById(Long id);

    /**
     * 查询酒店房间列表
     * 
     * @param shopRoom 酒店房间
     * @return 酒店房间集合
     */
    public List<ShopRoom> selectShopRoomList(ShopRoom shopRoom);

    public List<ShopRoom> selectShopRoomByShopId(Long shopId);

    /**
     * 新增酒店房间
     * 
     * @param shopRoom 酒店房间
     * @return 结果
     */
    public int insertShopRoom(ShopRoom shopRoom);

    /**
     * 修改酒店房间
     * 
     * @param shopRoom 酒店房间
     * @return 结果
     */
    public int updateShopRoom(ShopRoom shopRoom);

    /**
     * 批量删除酒店房间
     * 
     * @param ids 需要删除的酒店房间主键集合
     * @return 结果
     */
    public int deleteShopRoomByIds(Long[] ids);

    /**
     * 删除酒店房间信息
     * 
     * @param id 酒店房间主键
     * @return 结果
     */
    public int deleteShopRoomById(Long id);
}
